==> haskell-vault-0.3.1.2-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.1.2
id: vault-0.3.1.2-J2QxODP1CJ41GAbK6jEAv
key: vault-0.3.1.2-J2QxODP1CJ41GAbK6jEAv
license: BSD-3-Clause
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
author: Heinrich Apfelmus, Elliott Hird
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
abi: f44a4b8f0b63594626569d1b4aef2761
exposed: True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict
import-dirs: /usr/lib/ghc-8.6.5/site-local/vault-0.3.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/vault-0.3.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/vault-0.3.1.2
hs-libraries: HSvault-0.3.1.2-J2QxODP1CJ41GAbK6jEAv
depends:
    base-4.12.0.0 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    unordered-containers-0.2.10.0-FCaPs5fnhYpFgvItTiMoQE
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vault-0.3.1.2-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.1.2
id: vault-0.3.1.2-4neSl5b14wiEkl4vwF64VD
key: vault-0.3.1.2-4neSl5b14wiEkl4vwF64VD
license: BSD-3-Clause
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
author: Heinrich Apfelmus, Elliott Hird
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
abi: 53d6eb9991b1ec45924835d709d6b969
exposed: True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict
import-dirs: /usr/lib/ghc-8.6.5/site-local/vault-0.3.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/vault-0.3.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/vault-0.3.1.2
hs-libraries: HSvault-0.3.1.2-4neSl5b14wiEkl4vwF64VD
depends:
    base-4.12.0.0 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    unordered-containers-0.2.10.0-8dby3miKFglJ7BLkdgbDGw
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
